# Camera Calibration w/ Python + OpenCV
A wrapper around the main functionalities offered by OpenCV for camera calibration for cleaner and maintainable calibration routines.

## Dependencies
```
numpy (1.17.4 preferred)
opencv (3.4.2 preferred)
glob
os
tqdm
```

## Instructions

```
```
